@@ -73,7 +73,7 @@ elif importlib.util.find_spec("tensorflow"):
             model.save_weights(self.getPath(dataId))
 else:
     # ability to ignore missing model exporter for testing purposes
-    if os.environ.get("PYPHASESML_IGNORE_MISSING_MODEL_EXPORTER", False):
+    if os.environ.get("PYPHASESML_IGNORE_MISSING_MODEL_EXPORTER", 0) == 1:
         raise Exception("No supported ModelExporter located (Supported: pytorch/tensorflow)")
     else:
         class ModelExporter(DataExporter):
